@@ -25,50 +25,44 @@ class ModifyDBInstanceHAConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBInstanceHAConfig','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_DbInstanceId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DbInstanceId(self): # String
 		return self.get_query_params().get('DbInstanceId')
 
-	def set_DbInstanceId(self,DbInstanceId):
-		self.add_query_param('DbInstanceId',DbInstanceId)
-
-	def get_HAMode(self):
+	def set_DbInstanceId(self, DbInstanceId):  # String
+		self.add_query_param('DbInstanceId', DbInstanceId)
+	def get_HAMode(self): # String
 		return self.get_query_params().get('HAMode')
 
-	def set_HAMode(self,HAMode):
-		self.add_query_param('HAMode',HAMode)
-
-	def get_ResourceOwnerAccount(self):
+	def set_HAMode(self, HAMode):  # String
+		self.add_query_param('HAMode', HAMode)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_SyncMode(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_SyncMode(self): # String
 		return self.get_query_params().get('SyncMode')
 
-	def set_SyncMode(self,SyncMode):
-		self.add_query_param('SyncMode',SyncMode)
-
-	def get_OwnerId(self):
+	def set_SyncMode(self, SyncMode):  # String
+		self.add_query_param('SyncMode', SyncMode)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
