@@ -25,44 +25,39 @@ class ModifyDBInstanceProxyConfigurationRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBInstanceProxyConfiguration','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_ProxyConfigurationValue(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_ProxyConfigurationValue(self): # String
 		return self.get_query_params().get('ProxyConfigurationValue')
 
-	def set_ProxyConfigurationValue(self,ProxyConfigurationValue):
-		self.add_query_param('ProxyConfigurationValue',ProxyConfigurationValue)
-
-	def get_OwnerId(self):
+	def set_ProxyConfigurationValue(self, ProxyConfigurationValue):  # String
+		self.add_query_param('ProxyConfigurationValue', ProxyConfigurationValue)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_ProxyConfigurationKey(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_ProxyConfigurationKey(self): # String
 		return self.get_query_params().get('ProxyConfigurationKey')
 
-	def set_ProxyConfigurationKey(self,ProxyConfigurationKey):
-		self.add_query_param('ProxyConfigurationKey',ProxyConfigurationKey)
-
-	def get_DBInstanceId(self):
+	def set_ProxyConfigurationKey(self, ProxyConfigurationKey):  # String
+		self.add_query_param('ProxyConfigurationKey', ProxyConfigurationKey)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
\ No newline at end of file
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
